@@ -80,7 +80,7 @@ QVariant KFindItemModel::headerData(int section, Qt::Orientation orientation, in
 
 void KFindItemModel::insertFileItems(const QList< QPair<KFileItem, QString> > &pairs)
 {
-    if (pairs.size() > 0) {
+    if (!pairs.isEmpty()) {
         beginInsertRows(QModelIndex(), m_itemList.size(), m_itemList.size()+pairs.size()-1);
 
         QList< QPair<KFileItem, QString> >::const_iterator it = pairs.constBegin();
@@ -89,7 +89,7 @@ void KFindItemModel::insertFileItems(const QList< QPair<KFileItem, QString> > &p
         for (; it != end; ++it) {
             QPair<KFileItem, QString> pair = *it;
 
-            QString subDir = m_view->reducedDir(pair.first.url().adjusted(QUrl::RemoveFilename).path());
+            const QString subDir = m_view->reducedDir(pair.first.url().adjusted(QUrl::RemoveFilename).path());
             m_itemList.append(KFindItem(pair.first, subDir, pair.second));
         }
 
@@ -115,6 +115,11 @@ KFindItem KFindItemModel::itemAtIndex(const QModelIndex &index) const
     return KFindItem();
 }
 
+QList<KFindItem> KFindItemModel::getItemList() const
+{
+    return m_itemList;
+}
+
 QVariant KFindItemModel::data(const QModelIndex &index, int role) const
 {
     if (!index.isValid()) {
@@ -138,7 +143,7 @@ QVariant KFindItemModel::data(const QModelIndex &index, int role) const
 
 void KFindItemModel::removeItem(const QUrl &url)
 {
-    int itemCount = m_itemList.size();
+    const int itemCount = m_itemList.size();
     for (int i = 0; i < itemCount; i++) {
         KFindItem item = m_itemList.at(i);
         if (item.getFileItem().url() == url) {
@@ -152,7 +157,7 @@ void KFindItemModel::removeItem(const QUrl &url)
 
 bool KFindItemModel::isInserted(const QUrl &url)
 {
-    int itemCount = m_itemList.size();
+    const int itemCount = m_itemList.size();
     for (int i = 0; i < itemCount; i++) {
         KFindItem item = m_itemList.at(i);
         if (item.getFileItem().url() == url) {
@@ -171,9 +176,14 @@ void KFindItemModel::clear()
     }
 }
 
+Qt::DropActions KFindItemModel::supportedDropActions() const
+{
+    return Qt::CopyAction | Qt::MoveAction;
+}
+
 Qt::ItemFlags KFindItemModel::flags(const QModelIndex &index) const
 {
-    Qt::ItemFlags defaultFlags = Qt::ItemIsSelectable | Qt::ItemIsEnabled;
+    const Qt::ItemFlags defaultFlags = Qt::ItemIsSelectable | Qt::ItemIsEnabled;
     if (index.isValid()) {
         return Qt::ItemIsDragEnabled | defaultFlags;
     }
@@ -202,6 +212,12 @@ QMimeData *KFindItemModel::mimeData(const QModelIndexList &indexes) const
     return mimeData;
 }
 
+int KFindItemModel::columnCount(const QModelIndex &parent) const
+{
+    Q_UNUSED(parent);
+    return 6;
+}
+
 //END KFindItemModel
 
 //BEGIN KFindItem
@@ -276,6 +292,16 @@ QVariant KFindItem::data(int column, int role) const
     return QVariant();
 }
 
+KFileItem KFindItem::getFileItem() const
+{
+    return m_fileItem;
+}
+
+bool KFindItem::isValid() const
+{
+    return !m_fileItem.isNull();
+}
+
 //END KFindItem
 
 //BEGIN KFindSortFilterProxyModel
@@ -300,12 +326,10 @@ bool KFindSortFilterProxyModel::lessThan(const QModelIndex &left, const QModelIn
 
 KFindTreeView::KFindTreeView(QWidget *parent, KfindDlg *findDialog)
     : QTreeView(parent)
-    , m_contextMenu(nullptr)
+    , m_model(new KFindItemModel(this))
+    , m_proxyModel(new KFindSortFilterProxyModel(this))
     , m_kfindDialog(findDialog)
 {
-    //Configure model and proxy model
-    m_model = new KFindItemModel(this);
-    m_proxyModel = new KFindSortFilterProxyModel();
     m_proxyModel->setSourceModel(m_model);
     setModel(m_proxyModel);
 
@@ -376,6 +400,11 @@ QString KFindTreeView::reducedDir(const QString &fullDir)
     return fullDir;
 }
 
+int KFindTreeView::itemCount() const
+{
+    return m_model->rowCount();
+}
+
 void KFindTreeView::beginSearch(const QUrl &baseUrl)
 {
     m_baseDir = QDir(baseUrl.toLocalFile());
@@ -431,14 +460,17 @@ void KFindTreeView::removeItem(const QUrl &url)
     QList<QUrl> list = selectedUrls();
     if (list.contains(url)) {
         //Close menu
-        if (m_contextMenu) {
-            delete m_contextMenu;
-            m_contextMenu = nullptr;
-        }
+        delete m_contextMenu;
+        m_contextMenu = nullptr;
     }
     m_model->removeItem(url);
 }
 
+bool KFindTreeView::isInserted(const QUrl &url) const
+{
+    return m_model->isInserted(url);
+}
+
 // copy to clipboard
 void KFindTreeView::copySelection()
 {
@@ -588,7 +620,7 @@ void KFindTreeView::contextMenuRequested(const QPoint &p)
     KFileItemActions menuActions;
     KFileItemListProperties fileProperties(fileList);
     menuActions.setItemListProperties(fileProperties);
-    menuActions.addOpenWithActionsTo(m_contextMenu);
+    menuActions.insertOpenWithActionsTo(nullptr, m_contextMenu, QStringList());
     // 'Actions' submenu
     menuActions.addActionsTo(m_contextMenu);
 
@@ -607,7 +639,7 @@ void KFindTreeView::contextMenuRequested(const QPoint &p)
     m_contextMenu->exec(this->mapToGlobal(p));
 }
 
-QList<QUrl> KFindTreeView::selectedUrls()
+QList<QUrl> KFindTreeView::selectedUrls() const
 {
     QList<QUrl> uris;
 
@@ -673,4 +705,9 @@ void KFindTreeView::updateMouseButtons()
     m_mouseButtons = QApplication::mouseButtons();
 }
 
+void KFindTreeView::dragMoveEvent(QDragMoveEvent *e)
+{
+    e->accept();
+}
+
 //END KFindTreeView
