@@ -54,9 +54,6 @@ struct MimeTypes
 KfindTabWidget::KfindTabWidget(QWidget *parent)
     : QTabWidget(parent)
 {
-    // This validator will be used for all numeric edit fields
-    //KDigitValidator *digitV = new KDigitValidator(this);
-
     // ************ Page One ************
 
     pages[0] = new QWidget;
@@ -363,7 +360,7 @@ KfindTabWidget::KfindTabWidget(QWidget *parent)
     connect(watcher, &QFutureWatcher<MimeTypes>::finished, this, [this, watcher] {
         const MimeTypes &mimeTypes = watcher->result();
 
-        for (const auto &mime : qAsConst(mimeTypes.all)) {
+        for (const auto &mime : std::as_const(mimeTypes.all)) {
             typeBox->addItem(mime.comment());
         }
 
@@ -833,31 +830,6 @@ void KfindTabWidget::slotUpdateByteComboBox(int value)
     sizeUnitBox->setItemText(0, i18np("Byte", "Bytes", value));
 }
 
-/**
-   Digit validator. Allows only digits to be typed.
-**/
-KDigitValidator::KDigitValidator(QWidget *parent)
-    : QValidator(parent)
-{
-    r = new QRegExp(QStringLiteral("^[0-9]*$"));
-}
-
-KDigitValidator::~KDigitValidator()
-{
-    delete r;
-}
-
-QValidator::State KDigitValidator::validate(QString &input, int &) const
-{
-    if (r->indexIn(input) < 0) {
-        // Beep on user if he enters non-digit
-        QApplication::beep();
-        return QValidator::Invalid;
-    } else {
-        return QValidator::Acceptable;
-    }
-}
-
 //*******************************************************
 //             Static utility functions
 //*******************************************************
